(function ($, Drupal) {
  Drupal.behaviors.expandcollapse = {
    attach: function (context, settings) {
      $(document).ready(function(){

        $('.uw-expand-collapse').each(function() {

          // Get the id of the expand collapse.
          var id = '#uw-expand-collapse-' + $(this).data('id');

          // When the expand all button is clicked, expand all the items.
          $(id + ' [data-type="expand-all"]').click(function() {

            // Find each of the buttons, which are the titles and change
            // aria-expanded and add class to show expanded.
            $(id + ' .uw-expand-collapse__items button').each(function() {
              $(this).attr('aria-expanded', true);
              $(this).addClass('uw-expanded');
            });

            // Find each of the text and add css to display them.
            $(id + ' .uw-expand-collapse__items .uw-expand-collapse__text').each(function() {
              $(this).css('display', 'block');
            });
          });

          // When the collapse all button is clicked, collapse all the items.
          $(id + ' [data-type="collapse-all"]').click(function() {

            // Find each of the buttons, which are the titles and change
            // aria-expanded and remove class to show collapsed.
            $(id + ' .uw-expand-collapse__items button').each(function() {
              $(this).attr('aria-expanded', true);
              $(this).removeClass('uw-expanded');
            });

            // Find each of the text and add css to display them.
            $(id + ' .uw-expand-collapse__items .uw-expand-collapse__text').each(function() {
              $(this).css('display', 'none');
            });
          });

          // Step through each of the titles and add a click function.
          $(id + ' .uw-expand-collapse__items button').click(function() {

            // If this has an expanded class, remove it and change aria expanded to false.
            // Otherwise add the expanded class and set aria-expanded to true.
            if ($(this).hasClass('uw-expanded')) {
              $(this).attr('aria-expanded', false);
              $(this).removeClass('uw-expanded');
            }
            else {
              $(this).attr('aria-expanded', true);
              $(this).addClass('uw-expanded');
            }

            // Toggle the text to show/hide.
            $(this).parent().parent().find('.uw-expand-collapse__text').toggle();
          })
        });

      });
    }
  };
})(jQuery, Drupal);

(function ($, Drupal) {
  Drupal.behaviors.factfigure = {
    attach: function (context, settings) {
      $(document).ready(function(){

        // Step through each FF on the page.
        $('.uw-ff').each(function() {

          var result = $(this).find('.uw-ff__has-carousel-settings').length;

          // Get the id to reference the individual FF.
          // Need this to ensure that if more than one FF on the page,
          // that all FFs get the carousel added.
          var id = '#uw-ff-' + $(this).data('id');

          // Get the number of items for the carousel, if any.
          var num_of_items = $(id).data('num-per-carousel') !== '' ? $(this).data('num-per-carousel') : 3;

          // Add the carousel to the FF using the id.
          $(id + ' .owl-carousel').owlCarousel({
            loop: true,
            nav: true,
            margin: 10,
            responsiveClass: true,
            responsive: {
              0: {
                items: 1,
                nav: true,
                loop: true
              },
              600: {
                items: num_of_items <= 2 ? (num_of_items - 1 > 0) ? num_of_items - 1 : 1 : 2,
                nav: true,
                loop: true
              },
              1000: {
                items: num_of_items,
                nav: true,
                loop: true
              }
            }
          });
        });
      });
    }
  };
})(jQuery, Drupal);

(function ($, Drupal) {
  Drupal.behaviors.multitypelist = {
    attach: function (context, settings) {

      window.addEventListener("DOMContentLoaded", () => {
        const tabs = document.querySelectorAll('[role="tab"]');
        const tabList = document.querySelector('[role="tablist"]');

        // Add a click event handler to each tab
        tabs.forEach(tab => {
          tab.addEventListener("click", changeTabs);
        });

        // Enable arrow navigation between tabs in the tab list
        let tabFocus = 0;

        tabList.addEventListener("keydown", e => {
          // Move right
          if (e.keyCode === 39 || e.keyCode === 37) {
            tabs[tabFocus].setAttribute("tabindex", -1);
            if (e.keyCode === 39) {
              tabFocus++;
              // If we're at the end, go to the start
              if (tabFocus >= tabs.length) {
                tabFocus = 0;
              }
              // Move left
            } else if (e.keyCode === 37) {
              tabFocus--;
              // If we're at the start, move to the end
              if (tabFocus < 0) {
                tabFocus = tabs.length - 1;
              }
            }

            tabs[tabFocus].setAttribute("tabindex", 0);
            tabs[tabFocus].focus();
          }
        });
      });

      function changeTabs(e) {
        const target = e.target;
        const parent = target.parentNode;
        const grandparent = parent.parentNode;


        // Remove all current selected tabs
        parent
            .querySelectorAll('[aria-selected="true"]')
            .forEach(t => t.setAttribute("aria-selected", false));

        // Set this tab as selected
        target.setAttribute("aria-selected", true);

        // Hide all tab panels
        grandparent
            .querySelectorAll('[role="tabpanel"]')
            .forEach(p => p.setAttribute("hidden", true));

        // Show the selected panel
        grandparent.parentNode
            .querySelector(`#${target.getAttribute("aria-controls")}`)
            .removeAttribute("hidden");

      }
    }
  };
})(jQuery, Drupal);





